@@ -21,7 +21,8 @@
 
 # Imports
 from .              import utils
-from .base58        import Base58Encoder
+from .base58        import Base58Encoder, Base58Alphabets
+from .bch_bech32    import BchBech32Encoder
 from .bip_coin_conf import BitcoinConf
 from .key_helper    import KeyHelper
 
@@ -30,12 +31,13 @@ class P2PKH:
     """ P2PKH class. It allows the Pay-to-Public-Key-Hash address generation. """
 
     @staticmethod
-    def ToAddress(pub_key_bytes, net_addr_ver = BitcoinConf.P2PKH_NET_VER.Main()):
+    def ToAddress(pub_key_bytes, net_addr_ver = BitcoinConf.P2PKH_NET_VER.Main(), base58_alph = Base58Alphabets.BITCOIN):
         """ Get address in P2PKH format.
 
         Args:
-            pub_key_bytes (bytes)         : Public key bytes
-            net_addr_ver (bytes, optional): Net address version, default is Bitcoin main network
+            pub_key_bytes (bytes)                  : Public key bytes
+            net_addr_ver (bytes, optional)         : Net address version, default is Bitcoin main network
+            base58_alph (Base58Alphabets, optional): Base58 alphabet, Bitcoin by default
 
         Returns:
             str: Address string
@@ -46,4 +48,28 @@ class P2PKH:
         if not KeyHelper.IsPublicCompressed(pub_key_bytes):
             raise ValueError("Public compressed key is required for P2PKH")
 
-        return Base58Encoder.CheckEncode(net_addr_ver + utils.Hash160(pub_key_bytes))
+        return Base58Encoder.CheckEncode(net_addr_ver + utils.Hash160(pub_key_bytes), base58_alph)
+
+
+class BchP2PKH:
+    """ Bitcoin Cash P2PKH class. It allows the Bitcoin Cash P2PKH generation. """
+
+    @staticmethod
+    def ToAddress(pub_key_bytes, hrp, net_addr_ver):
+        """ Get address in Bitcoin Cash P2PKH format.
+
+        Args:
+            pub_key_bytes (bytes): Public key bytes
+            hrp (str)            : HRP
+            net_addr_ver (int)   : Net address version
+
+        Returns:
+            str: Address string
+
+        Raises:
+            ValueError: If key is not a public compressed key
+        """
+        if not KeyHelper.IsPublicCompressed(pub_key_bytes):
+            raise ValueError("Public compressed key is required for Bitcoin Cash")
+
+        return BchBech32Encoder.Encode(hrp, net_addr_ver, utils.Hash160(pub_key_bytes))
